4.4. umbra.components.addons.tcpClientUi.tcpClientUi — Umbra 1.0.9 documentation

# 4.4. umbra.components.addons.tcpClientUi.tcpClientUi

tcpClientUi.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `TCPClientUi` Component Interface class.

Others:

## 4.4.1. Module Attributes

`umbra.components.addons.tcpClientUi.tcpClientUi.` `LOGGER`

`umbra.components.addons.tcpClientUi.tcpClientUi.` `COMPONENT_UI_FILE`

## 4.4.2. Classes

class `umbra.components.addons.tcpClientUi.tcpClientUi.` `TCPClientUi`(parent=None, name=None, *args, **kwargs)

  Bases: `manager.qwidgetComponent.QWidgetComponent`

  Defines the `umbra.components.factory.tcpClientUi.tcpClientUi` Component Interface class.

  Initializes the class.

  Parameters: | parent (QObject) – Object parent. name (unicode) – Component name. *args (*) – Arguments. **kwargs (**) – Keywords arguments.

  `engine`

    Property for self.__engine attribute.

    Returns: | self.__engine.
    Return type: | QObject

  `settings`

    Property for self.__settings attribute.

    Returns: | self.__settings.
    Return type: | QSettings

  `settingsSection`

    Property for self.__settingsSection attribute.

    Returns: | self.__settingsSection.
    Return type: | unicode

  `preferencesManager`

    Property for self.__preferencesManager attribute.

    Returns: | self.__preferencesManager.
    Return type: | QWidget

  `scriptEditor`

    Property for self.__scriptEditor attribute.

    Returns: | self.__scriptEditor.
    Return type: | QWidget

  `address`

    Property for self.__address attribute.

    Returns: | self.__address.
    Return type: | unicode

  `port`

    Property for self.__port attribute.

    Returns: | self.__port.
    Return type: | int

  `fileCommand`

    Property for self.__fileCommand attribute.

    Returns: | self.__fileCommand.
    Return type: | unicode

  `connectionEnd`

    Property for self.__connectionEnd attribute.

    Returns: | self.__connectionEnd.
    Return type: | unicode

  `activate`(engine)

    Activates the Component.

    Parameters: | engine (QObject) – Engine to attach the Component to.
    Returns: | Method success.
    Return type: | bool

  `deactivate`()

    Deactivates the Component.

    Returns: | Method success.
    Return type: | bool

  `initializeUi`()

    Initializes the Component ui.

    Returns: | Method success.
    Return type: | bool

  `uninitializeUi`()

    Uninitializes the Component ui.

    Returns: | Method success.
    Return type: | bool

  `addWidget`()

    Adds the Component Widget to the engine.

    Returns: | Method success.
    Return type: | bool

  `removeWidget`()

    Removes the Component Widget from the engine.

    Returns: | Method success.
    Return type: | bool

  `sendDataToServer`(data, timeOut=5)

    Sends given data to the Server.

    Parameters: | data (unicode) – Data to send. timeOut (float) – Connection timeout in seconds.
    Returns: | Method success.
    Return type: | bool